@@ -30,7 +30,8 @@ from __future__ import absolute_import
 from .util import click_skip_on_help, click_force_option, UpperCaseChoice
 from ..device import device_config, FLAGS
 from ..util import APPLICATION
-from binascii import a2b_hex
+from binascii import a2b_hex, b2a_hex
+import os
 import logging
 import click
 
@@ -41,6 +42,10 @@ logger = logging.getLogger(__name__)
 CLEAR_LOCK_CODE = '0' * 32
 
 
+def prompt_lock_code(prompt='Enter your lock code'):
+    return click.prompt(prompt, default='', hide_input=True, show_default=False)
+
+
 @click.group()
 @click.pass_context
 @click_skip_on_help
@@ -60,27 +65,30 @@ def config(ctx):
 
 @config.command('set-lock-code')
 @click.pass_context
-@click.option('-l', '--lock-code', help='Current lock code.')
-@click.option('-n', '--new-lock-code', help='New lock code.')
+@click_force_option
+@click.option('-l', '--lock-code', metavar='HEX', help='Current lock code.')
+@click.option(
+    '-n', '--new-lock-code', metavar='HEX',
+    help='New lock code. Conflicts with --generate.')
 @click.option('-c', '--clear', is_flag=True, help='Clear the lock code.')
-def set_lock_code(ctx, lock_code, new_lock_code, clear):
+@click.option(
+    '-g', '--generate', is_flag=True,
+    help='Generate a random lock code. Conflicts with --new-lock-code.')
+def set_lock_code(ctx, lock_code, new_lock_code, clear, generate, force):
     """
     Set or change the configuration lock code.
 
-    A 16 byte lock code may be used to protect the application configuration.
+    A lock code may be used to protect the application configuration.
+    The lock code must be a 32 characters (16 bytes) hex value.
     """
 
     dev = ctx.obj['dev']
 
     def prompt_new_lock_code():
-        return click.prompt(
-                    'Enter your new lock code', default='', hide_input=True,
-                    show_default=False, confirmation_prompt=True)
+        return prompt_lock_code(prompt='Enter your new lock code')
 
     def prompt_current_lock_code():
-        return click.prompt(
-                    'Enter your current lock code', default='', hide_input=True,
-                    show_default=False)
+        return prompt_lock_code(prompt='Enter your current lock code')
 
     def change_lock_code(lock_code, new_lock_code):
         lock_code = _parse_lock_code(ctx, lock_code)
@@ -106,9 +114,19 @@ def set_lock_code(ctx, lock_code, new_lock_code, clear):
             logger.error('Setting the lock code failed', exc_info=e)
             ctx.fail('Failed to set the lock code.')
 
+    if generate and new_lock_code:
+        ctx.fail('Invalid options: --new-lock-code conflicts with --generate.')
+
     if clear:
         new_lock_code = CLEAR_LOCK_CODE
 
+    if generate:
+        new_lock_code = b2a_hex(os.urandom(16)).decode('utf-8')
+        click.echo(
+            'Using a randomly generated lock code: {}'.format(new_lock_code))
+        force or click.confirm(
+            'Lock configuration with this lock code?', abort=True)
+
     if dev.config.configuration_locked:
         if lock_code:
             if new_lock_code:
@@ -128,7 +146,7 @@ def set_lock_code(ctx, lock_code, new_lock_code, clear):
         if lock_code:
             ctx.fail(
                 'There is no current lock code set. '
-                'Use -n/--new-lock-code to set one.')
+                'Use --new-lock-code to set one.')
         else:
             if new_lock_code:
                 set_lock_code(new_lock_code)
@@ -150,8 +168,8 @@ def set_lock_code(ctx, lock_code, new_lock_code, clear):
 @click.option(
     '-a', '--enable-all', is_flag=True, help='Enable all applications.')
 @click.option(
-    '-L', '--lock-code',
-    help='A 16 byte lock code used to protect the application configuration.')
+    '-L', '--lock-code', metavar='HEX',
+    help='Current application configuration lock code.')
 @click.option(
     '--touch-eject', is_flag=True, help='When set, the button toggles the state'
     ' of the smartcard between ejected and inserted. (CCID only).')
@@ -212,9 +230,6 @@ def usb(
     if no_touch_eject:
         flags &= ~FLAGS.MODE_FLAG_EJECT
 
-    if lock_code:
-        lock_code = _parse_lock_code(ctx, lock_code)
-
     for app in enable:
         if APPLICATION[app] & usb_supported:
             usb_enabled |= APPLICATION[app]
@@ -242,7 +257,23 @@ def usb(
         'Set challenge-response timeout to {}.\n'.format(
             chalresp_timeout) if chalresp_timeout else '')
 
+    is_locked = dev.config.configuration_locked
+
+    if force and is_locked and not lock_code:
+        ctx.fail('Configuration is locked - please supply the --lock-code '
+                 'option.')
+    if lock_code and not is_locked:
+        ctx.fail('Configuration is not locked - please remove the '
+                 '--lock-code option.')
+
     force or click.confirm(f_confirm, abort=True)
+
+    if is_locked and not lock_code:
+        lock_code = prompt_lock_code()
+
+    if lock_code:
+        lock_code = _parse_lock_code(ctx, lock_code)
+
     try:
         dev.write_config(
             device_config(
@@ -272,8 +303,8 @@ def usb(
     '-D', '--disable-all', is_flag=True, help='Disable all applications')
 @click.option('-l', '--list', is_flag=True, help='List enabled applications')
 @click.option(
-    '-L', '--lock-code',
-    help='A 16 byte lock code used to protect the application configuration.')
+    '-L', '--lock-code', metavar='HEX',
+    help='Current application configuration lock code.')
 def nfc(ctx, enable, disable, enable_all, disable_all, list, lock_code, force):
     """
     Enable or disable applications over NFC.
@@ -290,9 +321,6 @@ def nfc(ctx, enable, disable, enable_all, disable_all, list, lock_code, force):
 
     _ensure_not_invalid_options(ctx, enable, disable)
 
-    if lock_code:
-        lock_code = _parse_lock_code(ctx, lock_code)
-
     dev = ctx.obj['dev']
     nfc_supported = dev.config.nfc_supported
     nfc_enabled = dev.config.nfc_enabled
@@ -322,7 +350,23 @@ def nfc(ctx, enable, disable, enable_all, disable_all, list, lock_code, force):
             ', '.join(
                 [str(APPLICATION[app]) for app in disable])) if disable else '')
 
+    is_locked = dev.config.configuration_locked
+
+    if force and is_locked and not lock_code:
+        ctx.fail('Configuration is locked - please supply the --lock-code '
+                 'option.')
+    if lock_code and not is_locked:
+        ctx.fail('Configuration is not locked - please remove the '
+                 '--lock-code option.')
+
     force or click.confirm(f_confirm, abort=True)
+
+    if is_locked and not lock_code:
+        lock_code = prompt_lock_code()
+
+    if lock_code:
+        lock_code = _parse_lock_code(ctx, lock_code)
+
     try:
         dev.write_config(
             device_config(
