@@ -172,7 +172,7 @@ def set_pin(ctx, pin, new_pin, u2f):
         controller.set_pin(new_pin)
 
     if pin and not controller.has_pin:
-        ctx.fail('There is no current PIN set. Use -n/--new-pin to set one.')
+        ctx.fail('There is no current PIN set. Use --new-pin to set one.')
 
     if controller.has_pin and pin is None and not is_fips:
         pin = _prompt_current_pin()
@@ -186,12 +186,8 @@ def set_pin(ctx, pin, new_pin, u2f):
         set_pin(new_pin)
 
 
-@click_force_option
 @fido.command('reset')
-@click.confirmation_option(
-            '-f', '--force', prompt='WARNING! This will delete '
-            'all FIDO credentials, including FIDO U2F credentials,'
-            ' and restore factory settings. Proceed?')
+@click_force_option
 @click.pass_context
 def reset(ctx, force):
     """
@@ -204,6 +200,16 @@ def reset(ctx, force):
     inserted, and requires a touch on the YubiKey.
     """
 
+    n_keys = len(list(get_descriptors()))
+    if n_keys > 1:
+        ctx.fail('Only one YubiKey can be connected to perform a reset.')
+
+    if not force:
+        if not click.confirm('WARNING! This will delete all FIDO credentials, '
+                             'including FIDO U2F credentials, and restore '
+                             'factory settings. Proceed?'):
+            ctx.abort()
+
     def prompt_re_insert_key():
         click.echo('Remove and re-insert your YubiKey to perform the reset...')
 
@@ -289,7 +295,7 @@ def unlock(ctx, pin):
     controller = ctx.obj['controller']
     if not controller.is_fips:
         ctx.fail('This is not a YubiKey FIPS, and therefore'
-                 'does not support a U2F PIN.')
+                 ' does not support a U2F PIN.')
 
     if pin is None:
         pin = _prompt_current_pin('Enter your PIN')
