@@ -158,15 +158,27 @@ def swap(ctx):
 @otp.command()
 @click_slot_argument
 @click.pass_context
-def ndef(ctx, slot):
+@click.option(
+    '-p', '--prefix', help='Added before the NDEF payload. Typically a URI.')
+def ndef(ctx, slot, prefix):
     """
     Select slot configuration to use for NDEF.
+
+    The default prefix will be used if no prefix is specified.
     """
+    dev = ctx.obj['dev']
     controller = ctx.obj['controller']
+    if not dev.config.nfc_supported:
+        ctx.fail('NFC interface not available.')
+
     if not controller.slot_status[slot - 1]:
         ctx.fail('Slot {} is empty.'.format(slot))
+
     try:
-        controller.configure_ndef_slot(slot)
+        if prefix:
+            controller.configure_ndef_slot(slot, prefix)
+        else:
+            controller.configure_ndef_slot(slot)
     except YkpersError as e:
         _failed_to_write_msg(ctx, e)
 
@@ -214,7 +226,8 @@ def delete(ctx, slot, force):
 @click_force_option
 @click.pass_context
 def yubiotp(ctx, slot, public_id, private_id, key, no_enter, force,
-            serial_public_id, generate_private_id, generate_key):
+            serial_public_id, generate_private_id,
+            generate_key):
     """
     Program a Yubico OTP credential.
 
@@ -523,7 +536,7 @@ def settings(ctx, slot, new_access_code, delete_access_code, enter, pacing,
     controller = ctx.obj['controller']
 
     if (new_access_code is not None) and delete_access_code:
-        ctx.fail('-A/--new-access-code conflicts with --delete-access-code.')
+        ctx.fail('--new-access-code conflicts with --delete-access-code.')
 
     if not controller.slot_status[slot - 1]:
         ctx.fail('Not possible to update settings on an empty slot.')
