@@ -98,6 +98,8 @@ def device_config(usb_enabled=None, nfc_enabled=None, flags=None,
             raise ValueError('Config lock key must be 16 bytes')
         _set_value(values, TAG.CONFIG_LOCK, config_lock)
     if usb_enabled is not None:
+        # Always add the unused CCID transport
+        usb_enabled |= TRANSPORT.CCID
         _set_value(values, TAG.USB_ENABLED, usb_enabled)
     if nfc_enabled is not None:
         _set_value(values, TAG.NFC_ENABLED, nfc_enabled)
@@ -257,6 +259,17 @@ class YubiKey(object):
                              APPLICATION.OPGP | APPLICATION.PIV)
         config._set(TAG.USB_ENABLED, usb_enabled)
 
+        # Workaround for invalid configurations.
+        # Assume all form factors except USB_A_KEYCHAIN
+        # does not support NFC.
+        if config.form_factor in (
+                FORM_FACTOR.USB_A_NANO,
+                FORM_FACTOR.USB_C_KEYCHAIN,
+                FORM_FACTOR.USB_C_NANO,
+                ):
+            config._set(TAG.NFC_SUPPORTED, 0)
+            config._set(TAG.NFC_ENABLED, 0)
+
         self._config = config
 
         if self._key_type == YUBIKEY.SKY:
@@ -265,8 +278,22 @@ class YubiKey(object):
                 logger.debug('SKY has no FIDO2, SKY 1')
                 self.device_name = 'FIDO U2F Security Key'  # SKY 1
         elif self._key_type == YUBIKEY.YK4:
-            if self.version >= (5, 0, 0):
+            if (5, 1, 0) > self.version >= (5, 0, 0):
                 self.device_name = 'YubiKey Preview'
+            elif self.version >= (5, 1, 0):
+                logger.debug('Identified YubiKey 5')
+                self.device_name = 'YubiKey 5'
+                if config.form_factor == FORM_FACTOR.USB_A_KEYCHAIN \
+                    and not config.nfc_supported:
+                    self.device_name += 'A'
+                elif config.form_factor == FORM_FACTOR.USB_A_KEYCHAIN:
+                    self.device_name += ' NFC'
+                elif config.form_factor == FORM_FACTOR.USB_A_NANO:
+                    self.device_name += ' Nano'
+                elif config.form_factor == FORM_FACTOR.USB_C_KEYCHAIN:
+                    self.device_name += 'C'
+                elif config.form_factor == FORM_FACTOR.USB_C_NANO:
+                    self.device_name += 'C Nano'
             elif self.is_fips:
                 self.device_name = 'YubiKey FIPS'
 
